# Appchance :: Backend Special Forces Team

Common django classes, configuration files and project automation.

## Installation
Install package with pip

    pip install appchance

## Subpackages
Tools includes

- `dodos` = project (docker & django) automation based on doit python package
- `pickup` = module for cart delivery pickup points clients
- `shop` = common models, serializers etc for django mcommerce

## Roadmap
Roadmap for future releases

* `0.2.0` = Sentry integrations
* `0.3.0` = ELK integrations
